public with sharing class TestSignatureImageExtraction {
    
    public void testSignatureImageExtraction(){
    	Folder folder = [select id from Folder where name='onespan' LIMIT 1]; 
        List<Document> documents = new List<Document>();
    	
    	//Get Signature Image For Sender 
    	String senderId = 'ATQOPd60xE4V';
    	Blob signatureImageForSender = getSignatureImageForSender(senderId);
		//store blob
        Document signatureImageForSenderDocument = new Document();
        signatureImageForSenderDocument.Body = signatureImageForSender;
        signatureImageForSenderDocument.FolderId = folder.id;
        signatureImageForSenderDocument.Name = 'Signature image for sender: '+ senderId +' - ' + Datetime.now().format();
        signatureImageForSenderDocument.Type = 'jpg';
        documents.add(signatureImageForSenderDocument);
        
        
        //Get Signature Image For Pacakge Role
        String packageId = 'E-cmEaSbHjLDNf631aj3Y8-hvCk=';
        String roleId = 'Signer2'; 
        Blob signatureImageForPackageRole = getSignatureImageForPackageRole(packageId,roleId);
		//store blob
        Document signatureImageForPackageRoleDocument = new Document();
        signatureImageForPackageRoleDocument.Body = signatureImageForPackageRole;
        signatureImageForPackageRoleDocument.FolderId = folder.id;
        signatureImageForPackageRoleDocument.Name = 'Signature image for signer: '+ roleId +' in package: '+ packageId +' - ' + Datetime.now().format();
        signatureImageForPackageRoleDocument.Type = 'jpg';
        documents.add(signatureImageForPackageRoleDocument);
        
        
        for(Document document: documents){
        	insert document;
        }
    
    }
    
    
    
    public Blob getSignatureImageForSender(String senderId){
        String resourceUrl = '/account/senders/' + senderId + '/signatureImage';
        HttpResponse response = doGet(resourceUrl);

		Blob signatureImageForSender;
        // Check response
        if(response.getStatusCode() == 200)
        {
            try
            {
                if(response.getBodyAsBlob() != null)
                {
                    signatureImageForSender = response.getBodyAsBlob();
                }
                else
                {
                    throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('No signature image found for the sender.');       
                }
            }
            catch(Exception e)
            {
                throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error obtaining the signature image for the sender: ' + e.getMessage());
            }
        }   
        else
        {
            throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error obtaining the signature image for the sender: ' + response.getStatusCode() + ' - ' + response.getStatus() + ' - ' +  response.getBody());
        }
        return signatureImageForSender;
    }
    
    
    public Blob getSignatureImageForPackageRole(String packageId, String roleId){
    	String resourceUrl = '/packages/' + packageId + '/roles/' + roleId + '/signatureImage';
        HttpResponse response = doGet(resourceUrl);

		Blob signatureImageForSender;
        // Check response
        if(response.getStatusCode() == 200)
        {
            try
            {
                if(response.getBodyAsBlob() != null)
                {
                    signatureImageForSender = response.getBodyAsBlob();
                }
                else
                {
                    throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('No signature image found for the role.');       
                }
            }
            catch(Exception e)
            {
                throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error obtaining the signature image for the role: ' + e.getMessage());
            }
        }   
        else
        {
            throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error obtaining the signature image for the role: ' + response.getStatusCode() + ' - ' + response.getStatus() + ' - ' +  response.getBody());
        }
        return signatureImageForSender;
    }
    
    private HttpResponse doGet(String resourceUrl){
        e_SignLive_Connection_Settings__c connectionSettings = e_SignLive_Connection_Settings__c.getInstance('Main');    
         // Build Request
        HttpRequest request = new HttpRequest();
        request.setEndpoint(connectionSettings.Endpoint__c + resourceUrl);
        request.setMethod('GET');
        request.setHeader('Authorization', 'Basic ' + connectionSettings.API_Key__c);
        request.setHeader('Content-type', 'application/json');

        // Send Request
        HttpResponse response = (new Http()).send(request);

        if(response != null && (response.getHeader('Content-Type')).contains('json'))
        {
            System.debug('=> Formating for JSON response');
            // Format responseBody string before returning
            String inboundResponseBody = ESignLiveJSONHelper.prepareInboundJSON(response.getBody());
            response.setBody(inboundResponseBody);
        }

        return response;
    }
    
}